.. include:: references.txt

.. warning::
    This ``regions`` package is in a very early stage of development.
    It is not feature complete or API stable!
    That said, please have a look and try to use it for your applications.
    Feedback and contributions welcome!


#############################
Astropy Regions Documentation
#############################

This is an in-development package for region handling based on Astropy.

To get an overview of available features, see :ref:`gs`.

The goal is to merge the functionality from `pyregion`_ and `photutils`_ apertures
and then after some time propose this package for inclusion in the Astropy core.

* Code : `Github repository`_
* Docs : `Region documentation`_
* Contributors : https://github.com/astropy/regions/graphs/contributors
* Releases: https://pypi.python.org/pypi/regions

.. toctree::
   :maxdepth: 1

   getting_started
   installation
   api
   development
